@@ -12,6 +12,7 @@ from uuid import getnode as get_mac
 import sys
 from pathlib import Path
 import subprocess
+import re
 
 downloads_path = str(Path.home() / "Downloads")
 
@@ -96,96 +97,28 @@ def list(search: str = typer.Argument("")):
         sock.close()
         tasks = json.loads(response.decode('utf-8'))
         mobLoadTasks(current_milli_time() - start_time)
-
         print_list = []
+        search_list = []
         for index, task in enumerate(tasks, 1):
-            print_item = [index, task['title'], task['ownerName'], task['emailPrefix']]
-            print_list.append(print_item)
-        typer.secho(tabulate(print_list, headers=["ID", "TITLE", "AUTHOR", "Email"], tablefmt='pretty'),
-                    fg=typer.colors.BLUE, bold=True)
-        typer.secho("\n")
+            if re.search(search, str(task['title']), re.IGNORECASE) or re.search(search, str(task['key']), re.IGNORECASE):
+                search_list.append(task)
+                print_item = [index, task['title'], task['ownerName'], task['emailPrefix']]
+                print_list.append(print_item)
 
-        task_id = typer.prompt("需要执行哪个任务? (输入ID)")
         execute_start = current_milli_time()
-        task = tasks[int(task_id) - 1]
-
-        if has_key(task['key']):
-            cache_list = []
-            input_item = [1, "重新输出参数"]
-            cache_list.append(input_item)
-            for cache_idx, cache in enumerate(get(task['key']), 2):
-                cache_item = [cache_idx, ','.join(cache['method']['params'])]
-                cache_list.append(cache_item)
-            typer.secho(tabulate(cache_list, headers=["ID", "Parameters"], tablefmt='pretty'), fg=typer.colors.BLUE,
-                        bold=True)
-            typer.secho("\n")
-
-            cache_id = typer.prompt("选择缓存项")
-
-            if cache_id == '1':
-                input_params(task)
-            else:
-                task = get(task['key'])[int(cache_id) - 2]
+        if len(search_list) == 1:
+            execute_task(execute_start, search_list[0])
+        elif len(search_list) == 0:
+            typer.secho("请检查任务过滤关键词")
         else:
-            input_params(task)
-
-        rsock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        rsock.connect((HOST, PC_PORT))
-        rsock.send(FIRST_TASK_TAG.encode())
-        rsock.send("\n".encode())
-        rsock.send(json.dumps(task).encode())
-        rsock.send("\n".encode())
-        response = get_all_data(rsock)
-        rsock.close()
-
-        put(task)
-
-        mobExecuteMethodEvent(task['key'], current_milli_time() - execute_start)
-
-        if task['outputType'] == 0:
-            pyperclip.copy(response.decode("utf-8"))
-            typer.secho(str(response.decode('utf-8')), fg=typer.colors.BLUE, bold=True)
-        elif task['outputType'] == 2:
-            time_str = timer.strftime("%Y-%m-%d-%H_%M_%S")
-            file_name = downloads_path + time_str + ".json"
-
-            typer.secho("Output file path: " + file_name)
-
-            try:
-                f = open(file_name, 'w')
-                f.write(json.dumps(json.loads(response)))
-                f.close()
-
-                os.system("open " + file_name)
-            except Exception:
-                typer.secho("JSON 格式异常，请检查输出是否为JSON文件", err=True)
-        else:
-            # 列表结果
-            list_tasks = json.loads(response.decode('utf-8'))
-
-            print_list = []
-            for index, task in enumerate(list_tasks, 1):
-                print_item = [index, task['title'], task['subTitle']]
-                print_list.append(print_item)
-            typer.secho(tabulate(print_list, headers=["ID", "TITLE", "SUBTITLE"], tablefmt='simple'),
+            typer.secho(tabulate(print_list, headers=["ID", "TITLE", "AUTHOR", "Email"], tablefmt='pretty'),
                         fg=typer.colors.BLUE, bold=True)
             typer.secho("\n")
 
-            selected_index = typer.prompt("选择其中一个选项(输入ID)")
-            selected_task = list_tasks[int(selected_index) - 1]
+            task_id = typer.prompt("需要执行哪个任务? (输入ID)")
+            task = tasks[int(task_id) - 1]
 
-            print_list = []
-            for index, task in enumerate(selected_task['options'], 1):
-                print_item = [index, task['title'], task['subTitle']]
-                print_list.append(print_item)
-            typer.secho(tabulate(print_list, headers=["ID", "TITLE", "SUBTITLE"], tablefmt='simple'),
-                        fg=typer.colors.BLUE, bold=True)
-            typer.secho("\n")
-
-            option_index = int(typer.prompt("选择操作项(输入ID)")) - 1
-            selected_start_time = current_milli_time()
-            executed_method(json.dumps(selected_task['options'][option_index]))
-            mobExecuteMethodEvent(selected_task['key'], current_milli_time() - selected_start_time)
+            execute_task(execute_start, task)
     except Exception:
         typer.secho("\n")
         typer.secho("执行异常，可能的原因如下：", err=True)
@@ -194,6 +127,82 @@ def list(search: str = typer.Argument("")):
         typer.secho("\t 3. 中断任务执行", err=True)
 
 
+def execute_task(execute_start, task):
+    if has_key(task['key']):
+        cache_list = []
+        input_item = [1, "重新输出参数"]
+        cache_list.append(input_item)
+        for cache_idx, cache in enumerate(get(task['key']), 2):
+            cache_item = [cache_idx, ','.join(cache['method']['params'])]
+            cache_list.append(cache_item)
+        typer.secho(tabulate(cache_list, headers=["ID", "Parameters"], tablefmt='pretty'), fg=typer.colors.BLUE,
+                    bold=True)
+        typer.secho("\n")
+
+        cache_id = typer.prompt("选择缓存项")
+
+        if cache_id == '1':
+            input_params(task)
+        else:
+            task = get(task['key'])[int(cache_id) - 2]
+    else:
+        input_params(task)
+    rsock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    rsock.connect((HOST, PC_PORT))
+    rsock.send(FIRST_TASK_TAG.encode())
+    rsock.send("\n".encode())
+    rsock.send(json.dumps(task).encode())
+    rsock.send("\n".encode())
+    response = get_all_data(rsock)
+    rsock.close()
+    put(task)
+    mobExecuteMethodEvent(task['key'], current_milli_time() - execute_start)
+    if task['outputType'] == 0:
+        pyperclip.copy(response.decode("utf-8"))
+        typer.secho(str(response.decode('utf-8')), fg=typer.colors.BLUE, bold=True)
+    elif task['outputType'] == 2:
+        time_str = timer.strftime("%Y-%m-%d-%H_%M_%S")
+        file_name = downloads_path + time_str + ".json"
+
+        typer.secho("Output file path: " + file_name)
+
+        try:
+            f = open(file_name, 'w')
+            f.write(json.dumps(json.loads(response)))
+            f.close()
+
+            os.system("open " + file_name)
+        except Exception:
+            typer.secho("JSON 格式异常，请检查输出是否为JSON文件", err=True)
+    else:
+        # 列表结果
+        list_tasks = json.loads(response.decode('utf-8'))
+
+        print_list = []
+        for index, task in enumerate(list_tasks, 1):
+            print_item = [index, task['title'], task['subTitle']]
+            print_list.append(print_item)
+        typer.secho(tabulate(print_list, headers=["ID", "TITLE", "SUBTITLE"], tablefmt='simple'),
+                    fg=typer.colors.BLUE, bold=True)
+        typer.secho("\n")
+
+        selected_index = typer.prompt("选择其中一个选项(输入ID)")
+        selected_task = list_tasks[int(selected_index) - 1]
+
+        print_list = []
+        for index, task in enumerate(selected_task['options'], 1):
+            print_item = [index, task['title'], task['subTitle']]
+            print_list.append(print_item)
+        typer.secho(tabulate(print_list, headers=["ID", "TITLE", "SUBTITLE"], tablefmt='simple'),
+                    fg=typer.colors.BLUE, bold=True)
+        typer.secho("\n")
+
+        option_index = int(typer.prompt("选择操作项(输入ID)")) - 1
+        selected_start_time = current_milli_time()
+        executed_method(json.dumps(selected_task['options'][option_index]))
+        mobExecuteMethodEvent(selected_task['key'], current_milli_time() - selected_start_time)
+
+
 def input_params(task):
     params_hint = task['method']['paramsHint']
     # Input Params
